package com.xkrs.straw.model.entity;

import javax.persistence.*;
import java.io.Serializable;

/**
 * 未审核的普通火点
 */
@Entity
@Table(name = "fire_point_ordinary")
public class FirePointOrdinaryEntity implements Serializable {

    /**
     * 指定主键，建立自增序列，主键值取自序列
     */
    @Id
    @GeneratedValue(strategy = GenerationType.SEQUENCE, generator = "fire_point_ordinary_seq_gen")
    @SequenceGenerator(name = "fire_point_ordinary_seq_gen", sequenceName = "fire_point_ordinary_id_seq", allocationSize = 1)
    private Integer id;

    /**
     * 火点编码
     */
    @Column(length = 32, unique = true, columnDefinition = "varchar(32)")
    private String fireCode;
    /**
     * 省市区的编码
     */
    @Column(length = 32, columnDefinition = "varchar(32)")
    private Long countyCode;
    /**
     * 省市区的名称
     */
    @Column(length = 64, columnDefinition = "varchar(64)")
    private String countyName;
    /**
     * 卫星监测的时间
     */
    @Column(length = 64, columnDefinition = "varchar(64)")
    private String satelliteTime;
    /**
     * 经度
     */
    private Double longitude;
    /**
     * 纬度
     */
    private Double latitude;
    /**
     * 卫星类型
     */
    @Column(length = 64, columnDefinition = "varchar(64)")
    private String satelliteType;
    /**
     * 植被类型
     */
    @Column(length = 64, columnDefinition = "varchar(64)")
    private String landType;
    /**
     * 置信度
     */
    @Column(length = 32, columnDefinition = "varchar(32)")
    private String confidence;
    /**
     * 当前火点的图片
     */
    @Column(length = 512, columnDefinition = "varchar(512)")
    private String fireImage;
    /**
     * 卫星影像图片
     */
    @Column(length = 512, columnDefinition = "varchar(512)")
    private String satelliteImage;
    /**
     * 乡镇街道的编码
     */
    @Column(length = 64, columnDefinition = "varchar(64)")
    private String townCode;
    /**
     * 乡镇街道的名字
     */
    @Column(length = 85, columnDefinition = "varchar(85)")
    private String townName;
    /**
     * 添加的时间
     */
    @Column(length = 64, columnDefinition = "varchar(64)")
    private String addTime;
    /**
     * 详细地址
     */
    @Column(length = 255, columnDefinition = "varchar(255)")
    private String firePointAddress;

    public FirePointOrdinaryEntity() {
    }

    public Integer getId() {
        return id;
    }

    public void setId(Integer id) {
        this.id = id;
    }

    public String getFireCode() {
        return fireCode;
    }

    public void setFireCode(String fireCode) {
        this.fireCode = fireCode;
    }

    public Long getCountyCode() {
        return countyCode;
    }

    public void setCountyCode(Long countyCode) {
        this.countyCode = countyCode;
    }

    public String getCountyName() {
        return countyName;
    }

    public void setCountyName(String countyName) {
        this.countyName = countyName;
    }

    public String getSatelliteTime() {
        return satelliteTime;
    }

    public void setSatelliteTime(String satelliteTime) {
        this.satelliteTime = satelliteTime;
    }

    public Double getLongitude() {
        return longitude;
    }

    public void setLongitude(Double longitude) {
        this.longitude = longitude;
    }

    public Double getLatitude() {
        return latitude;
    }

    public void setLatitude(Double latitude) {
        this.latitude = latitude;
    }

    public String getSatelliteType() {
        return satelliteType;
    }

    public void setSatelliteType(String satelliteType) {
        this.satelliteType = satelliteType;
    }

    public String getLandType() {
        return landType;
    }

    public void setLandType(String landType) {
        this.landType = landType;
    }

    public String getConfidence() {
        return confidence;
    }

    public void setConfidence(String confidence) {
        this.confidence = confidence;
    }

    public String getFireImage() {
        return fireImage;
    }

    public void setFireImage(String fireImage) {
        this.fireImage = fireImage;
    }

    public String getSatelliteImage() {
        return satelliteImage;
    }

    public void setSatelliteImage(String satelliteImage) {
        this.satelliteImage = satelliteImage;
    }

    public String getTownCode() {
        return townCode;
    }

    public void setTownCode(String townCode) {
        this.townCode = townCode;
    }

    public String getTownName() {
        return townName;
    }

    public void setTownName(String townName) {
        this.townName = townName;
    }

    public String getAddTime() {
        return addTime;
    }

    public void setAddTime(String addTime) {
        this.addTime = addTime;
    }

    public String getFirePointAddress() {
        return firePointAddress;
    }

    public void setFirePointAddress(String firePointAddress) {
        this.firePointAddress = firePointAddress;
    }

    @Override
    public String toString() {
        return "FirePointOrdinaryEntity{" + "id=" + id + ", fireCode='" + fireCode + '\'' + ", countyCode=" + countyCode + ", countyName='" + countyName + '\'' + ", satelliteTime='" + satelliteTime + '\'' + ", longitude=" + longitude + ", latitude=" + latitude + ", satelliteType='" + satelliteType + '\'' + ", landType='" + landType + '\'' + ", confidence='" + confidence + '\'' + ", fireImage='" + fireImage + '\'' + ", satelliteImage='" + satelliteImage + '\'' + ", townCode='" + townCode + '\'' + ", townName='" + townName + '\'' + ", addTime='" + addTime + '\'' + ", firePointAddress='" + firePointAddress + '\'' + '}';
    }
}
